bayespy.inference.vmp.nodes.gaussian.GaussianARDDistribution.compute_phi_from_parents
=====================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianARDDistribution.compute_phi_from_parents